/*******************************************************
FEED PARSER
Version 0.7 b20040425

All code by Ryan Parman, unless otherwise noted.
(c) 2004, Ryan Parman, http://www.skyzyx.com
Distributed according to SkyGPL 2.1, http://www.skyzyx.com/license/
*******************************************************/


/*******************************************************
INITIALIZE GLOBAL VARIABLES
*******************************************************/
var gecko= (document.implementation && document.implementation.createDocument) ? true:false;


/*******************************************************
WHITESPACE CLEANER FOR MOZILLA
By Alex Vincent, http://weblogs.mozillazine.org/weirdal/
*******************************************************/
const notWhitespace = /\S/

function cleanWhitespace(node) {
    for (var x = 0; x < node.childNodes.length; x++) {
	var childNode = node.childNodes[x];
	if ((childNode.nodeType == 3)&&(!notWhitespace.test(childNode.nodeValue))) {
	    node.removeChild(node.childNodes[x]);
	    x--;
	}
	if (childNode.nodeType == 1) {
	    cleanWhitespace(childNode);
	}
    }
}


/*******************************************************
FIX MIMETYPES/DOCUMENT HEADERS FOR GECKO
By Vladdy, http://www.klproductions.com/
*******************************************************/
function fixXmlMimeType(filename)
{
    oxmlhttp = null;

    try {
	oxmlhttp = new XMLHttpRequest();
	oxmlhttp.overrideMimeType("text/xml");
    } catch(e) {
	try { oxmlhttp = new ActiveXObject("Msxml2.XMLHTTP"); }
	catch(e) { return null; }
    }

    if (!oxmlhttp) return null;

    try {
	// Gecko must have this security priviledge enabled.
	if (gecko) netscape.security.PrivilegeManager.enablePrivilege("UniversalBrowserRead");

	oxmlhttp.open("GET", filename, false);
	oxmlhttp.send(null);
    } catch(e) { return null; }

    return oxmlhttp.responseXML;
}


/*******************************************************
"FAMILIAL-HEIRARCHY" NODE DEPTH FIX (WITH CASE-INSENSITIVITY)
By David "Liorean" Andersson, http://liorean.web-graphics.com/
*******************************************************/
function getChildrenByTagName(oParent, sTagName)
{
    // alert("Called with " + oParent + "," + sTagName);
    var i=0, aResults=[], oTemp;
    var reTagName = new RegExp('^'+sTagName+'$', 'i');

    while ((oTemp=oParent.childNodes.item(i++))) {
	if (reTagName.test(oTemp.nodeName)) aResults.push(oTemp);
    }

    return aResults;
}


/*******************************************************
CREATE PARSING OBJECT
*******************************************************/
function FeedParser(rssFeedUrl)
{
    var xmlFeed=false;
    if (xmlFeed === false) xmlFeed = fixXmlMimeType(rssFeedUrl);

    // Feed Parser core data
    this.fp = new Object();
    this.fp.author = "Ryan Parman"
    this.fp.contributors = "David Andersson, Vladdy, and Alex Vincent"
    this.fp.copyright = "2004";
    this.fp.name = "Feed Parser"
    this.fp.url = "http://www.skyzyx.com/projects/feedparser/";
    this.fp.version = "0.7b";
    this.fp.build = "20040425";

    // RSS Feed URL
    this.feedUrl = rssFeedUrl;

    // Gecko must have this security priviledge enabled.
    if (gecko) netscape.security.PrivilegeManager.enablePrivilege("UniversalBrowserRead");

    // Set this.type, this.type[Format], and clean whitespace from all XML nodes.
    this.typeRSS = false; this.typeRDF = false; this.typeAtom = false;
    if (xmlFeed.getElementsByTagName('rss')[0]) { 
	this.type = "RSS"; this.typeRSS = true; 
	cleanWhitespace(xmlFeed.getElementsByTagName('rss')[0]); 
    } else if (xmlFeed.getElementsByTagName('RDF')[0]) { 
	this.type = "RDF"; this.typeRDF = true; 
	cleanWhitespace(xmlFeed.getElementsByTagName('RDF')[0]); 
    } else if (xmlFeed.getElementsByTagName('feed')[0]) { 
	this.type = "Atom"; this.typeAtom = true; 
	cleanWhitespace(xmlFeed.getElementsByTagName('feed')[0]); 
    } else this.type = false;

    this.version = (this.typeRSS) ? xmlFeed.getElementsByTagName('rss')[0].getAttribute('version') : (this.typeRDF) ? "1.0" : (this.typeAtom) ? xmlFeed.getElementsByTagName('feed')[0].getAttribute('version') : "0.0";

    var MasterElem;
    if (this.typeRSS) {
	MasterElem = xmlFeed.getElementsByTagName('rss')[0];
    } else if (this.typeRDF) {
	MasterElem = xmlFeed.getElementsByTagName('RDF')[0];
    } else if (this.typeAtom) {
	MasterElem = xmlFeed.getElementsByTagName('feed')[0];
    }
    this.nsDefault = (MasterElem.getAttribute('xmlns')) ? MasterElem.getAttribute('xmlns') : false;
    this.nsRDF = (MasterElem.getAttribute('xmlns:rdf')) ? MasterElem.getAttribute('xmlns:rdf') : false;
    this.nsDC = (MasterElem.getAttribute('xmlns:dc')) ? MasterElem.getAttribute('xmlns:dc') : false;
    this.nsSY = (MasterElem.getAttribute('xmlns:sy')) ? MasterElem.getAttribute('xmlns:sy') : false;
    this.nsAdmin = (MasterElem.getAttribute('xmlns:admin')) ? MasterElem.getAttribute('xmlns:admin') : false;
    // RDF-style namespace
    this.nsCC = (MasterElem.getAttribute('xmlns:cc')) ? MasterElem.getAttribute('xmlns:cc') : false;
    // RSS-style namespace
    this.nsCC = (this.nsCC) ? this.nsCC : (MasterElem.getAttribute('xmlns:creativeCommons')) ? MasterElem.getAttribute('xmlns:creativeCommons') : false;


    /*******************************************************
    Begin parsing the RSS 0.9x/2.0 specification.
    *******************************************************/
    if (this.typeRSS) {
	// Master RSS Element
	var RSSElem = xmlFeed.getElementsByTagName('rss')[0];

	// Channel
	var RSSChannel = getChildrenByTagName(RSSElem, 'channel')[0];
	this.channel = new Object();
	this.channel.readTag = RSSChannel;

	// Required tags.  Parsing will fail without these.
	this.channel.title = getChildrenByTagName(RSSChannel, 'title')[0].firstChild.data;

	try {
	    this.channel.link = getChildrenByTagName(RSSChannel, 'link')[0].firstChild.data;
	} catch (e) {
	    this.channel.link = '';
	}

	try {
	    this.channel.description = getChildrenByTagName(RSSChannel, 'description')[0].firstChild.data;
	} catch (e) {
	    this.channel.description = 'No description available';
	}


	// Optional Tags
	try {
	    this.channel.category = getChildrenByTagName(RSSChannel, 'category')[0].firstChild.data;
	} catch (e) {
	    this.channel.category = false;
	}
	try {
	    this.channel.copyright = getChildrenByTagName(RSSChannel, 'copyright')[0].firstChild.data;
	} catch (e) {
	    this.channel.copyright = false;
	}

	/*
	try {
	    this.channel.docs = getChildrenByTagName(RSSChannel, 'docs')[0].firstChild.data;
	} catch (e) {
	    this.channel.docs = false;
	}
	try {
	    this.channel.generator = getChildrenByTagName(RSSChannel, 'generator')[0].firstChild.data;
	} catch (e) {
	    this.channel.generator = false;
	}
	try {
	    this.channel.language = getChildrenByTagName(RSSChannel, 'language')[0].firstChild.data;
	} catch (e) {
	    this.channel.language = false;
	}
	    try {
	    this.channel.lastBuildDate = getChildrenByTagName(RSSChannel, 'lastBuildDate')[0].firstChild.data
	} catch (e) {
	    this.channel.lastBuildDate = false;
	}
	try {
	    this.channel.managingEditor = getChildrenByTagName(RSSChannel, 'managingEditor')[0].firstChild.data
	} catch (e) {
	    this.channel.managingEditor = false;
	}
	try {
	    this.channel.pubDate = getChildrenByTagName(RSSChannel, 'pubDate')[0].firstChild.data
	} catch (e) {
	    this.channel.pubDate = false;
	}
	try {
	    this.channel.rating = getChildrenByTagName(RSSChannel, 'rating')[0].firstChild.data
	} catch (e) {
	    this.channel.rating = false;
	}
	try {
	    this.channel.ttl = getChildrenByTagName(RSSChannel, 'ttl')[0].firstChild.data
	} catch (e) {
	    this.channel.ttl = false;
	}
	try {
	    this.channel.webMaster = getChildrenByTagName(RSSChannel, 'webMaster')[0].firstChild.data
	} catch (e) {
	    this.channel.webMaster = false;
	}
	*/
	try {
	    this.channel.ccLicense = getChildrenByTagName(RSSChannel, 'ccLicense')[0].firstChild.data
	} catch (e) {
	    this.channel.ccLicense = false;
	}

	// Creative Commons <license> tag
	// this.channel.ccLicense = (getChildrenByTagName(RSSChannel, 'license')[0]) ? getChildrenByTagName(RSSChannel, 'license')[0].firstChild.data : false;

	// <skipDays> and <day>
	/*
	// The following commented out because HX is not that smart yet
	RSSSkipDays = (getChildrenByTagName(RSSChannel, 'skipDays')[0]) ? getChildrenByTagName(RSSChannel, 'skipDays')[0] : false;
	this.channel.skipDays = new Object();
	this.channel.skipDays.day = new Array();
	if (RSSSkipDays) {
	    for (var m=0; m<getChildrenByTagName(RSSSkipDays, 'day').length; m++) {
		this.channel.skipDays.day[m] = getChildrenByTagName(RSSSkipDays, 'day')[m].firstChild.data;
	    }
	}

	// <skipHours> and <hour>
	RSSSkipHours = (getChildrenByTagName(RSSChannel, 'skipHours')[0]) ? getChildrenByTagName(RSSChannel, 'skipHours')[0] : false;
	this.channel.skipHours = new Object();
	this.channel.skipHours.hour = new Array();
	if (RSSSkipHours) {
	    for (var n=0; n<getChildrenByTagName(RSSSkipHours, 'hour').length; n++) {
		this.channel.skipHours.hour[n] = getChildrenByTagName(RSSSkipHours, 'hour')[n].firstChild.data;
	    }
	}

	// <cloud> tag
	this.channel.cloud = (getChildrenByTagName(RSSChannel, 'cloud')[0]) ? getChildrenByTagName(RSSChannel, 'cloud')[0] : false;
	// Since these attributes are required if <cloud> is used, we will only check if <cloud> exists.
	this.channel.cloud_domain = (getChildrenByTagName(RSSChannel, 'cloud')[0]) ? getChildrenByTagName(RSSChannel, 'cloud')[0].getAttribute('domain') : false;
	this.channel.cloud_path = (getChildrenByTagName(RSSChannel, 'cloud')[0]) ? getChildrenByTagName(RSSChannel, 'cloud')[0].getAttribute('path') : false;
	this.channel.cloud_port = (getChildrenByTagName(RSSChannel, 'cloud')[0]) ? getChildrenByTagName(RSSChannel, 'cloud')[0].getAttribute('port') : false;
	this.channel.cloud_protocol = (getChildrenByTagName(RSSChannel, 'cloud')[0]) ? getChildrenByTagName(RSSChannel, 'cloud')[0].getAttribute('protocol') : false;
	this.channel.cloud_registerProcedure = (getChildrenByTagName(RSSChannel, 'cloud')[0]) ? getChildrenByTagName(RSSChannel, 'cloud')[0].getAttribute('registerProcedure') : false;

	// <image>
	var RSSImage = (getChildrenByTagName(RSSChannel, 'image')[0]) ? getChildrenByTagName(RSSChannel, 'image')[0] : false;
	this.channel.image = new Object();
	this.channel.image.title = (RSSImage && getChildrenByTagName(RSSImage, 'title')[0]) ? getChildrenByTagName(RSSImage, 'title')[0].firstChild.data : false;
	this.channel.image.url = (RSSImage && getChildrenByTagName(RSSImage, 'url')[0]) ? getChildrenByTagName(RSSImage, 'url')[0].firstChild.data : false;
	this.channel.image.link = (RSSImage && getChildrenByTagName(RSSImage, 'link')[0]) ? getChildrenByTagName(RSSImage, 'link')[0].firstChild.data : false;
	this.channel.image.width = (RSSImage && getChildrenByTagName(RSSImage, 'width')[0]) ? getChildrenByTagName(RSSImage, 'width')[0].firstChild.data : false;
	this.channel.image.height = (RSSImage && getChildrenByTagName(RSSImage, 'height')[0]) ? getChildrenByTagName(RSSImage, 'height')[0].firstChild.data : false;

	// Dublin Core
	this.channel.image.dcContributor = (RSSImage && getChildrenByTagName(RSSImage, 'contributor')[0]) ? getChildrenByTagName(RSSImage, 'contributor')[0].firstChild.data : false;
	this.channel.image.dcCoverage = (RSSImage && getChildrenByTagName(RSSImage, 'coverage')[0]) ? getChildrenByTagName(RSSImage, 'coverage')[0].firstChild.data : false;
	this.channel.image.dcCreator = (RSSImage && getChildrenByTagName(RSSImage, 'creator')[0]) ? getChildrenByTagName(RSSImage, 'creator')[0].firstChild.data : false;
	this.channel.image.dcDate = (RSSImage && getChildrenByTagName(RSSImage, 'date')[0]) ? getChildrenByTagName(RSSImage, 'date')[0].firstChild.data : false;
	this.channel.image.dcDescription = (RSSImage && getChildrenByTagName(RSSImage, 'description')[0]) ? getChildrenByTagName(RSSImage, 'description')[0].firstChild.data : false;
	this.channel.image.dcFormat = (RSSImage && getChildrenByTagName(RSSImage, 'format')[0]) ? getChildrenByTagName(RSSImage, 'format')[0].firstChild.data : false;
	this.channel.image.dcIdentifier = (RSSImage && getChildrenByTagName(RSSImage, 'identifier')[0]) ? getChildrenByTagName(RSSImage, 'identifier')[0].firstChild.data : false;
	this.channel.image.dcLanguage = (RSSImage && getChildrenByTagName(RSSImage, 'language')[0]) ? getChildrenByTagName(RSSImage, 'language')[0].firstChild.data : false;
	this.channel.image.dcPublisher = (RSSImage && getChildrenByTagName(RSSImage, 'publisher')[0]) ? getChildrenByTagName(RSSImage, 'publisher')[0].firstChild.data : false;
	this.channel.image.dcRelation = (RSSImage && getChildrenByTagName(RSSImage, 'relation')[0]) ? getChildrenByTagName(RSSImage, 'relation')[0].firstChild.data : false;
	this.channel.image.dcRights = (RSSImage && getChildrenByTagName(RSSImage, 'rights')[0]) ? getChildrenByTagName(RSSImage, 'rights')[0].firstChild.data : false;
	this.channel.image.dcSource = (RSSImage && getChildrenByTagName(RSSImage, 'source')[0]) ? getChildrenByTagName(RSSImage, 'source')[0].firstChild.data : false;
	this.channel.image.dcSubject = (RSSImage && getChildrenByTagName(RSSImage, 'subject')[0]) ? getChildrenByTagName(RSSImage, 'subject')[0].firstChild.data : false;
	this.channel.image.dcTitle = (RSSImage && getChildrenByTagName(RSSImage, 'title')[0]) ? getChildrenByTagName(RSSImage, 'title')[0].firstChild.data : false;
	this.channel.image.dcType = (RSSImage && getChildrenByTagName(RSSImage, 'type')[0]) ? getChildrenByTagName(RSSImage, 'type')[0].firstChild.data : false;

	// <textInput>
	var RSSTextInput = (getChildrenByTagName(RSSChannel, 'textInput')[0]) ? getChildrenByTagName(RSSChannel, 'textInput')[0] : false;
	this.channel.textInput = new Object();
	this.channel.textInput.title = (getChildrenByTagName(RSSChannel, 'textInput')[0]) ? getChildrenByTagName(RSSTextInput, 'title')[0].firstChild.data : false;
	this.channel.textInput.description = (getChildrenByTagName(RSSChannel, 'textInput')[0]) ? getChildrenByTagName(RSSTextInput, 'description')[0].firstChild.data : false;
	this.channel.textInput.link = (getChildrenByTagName(RSSChannel, 'textInput')[0]) ? getChildrenByTagName(RSSTextInput, 'link')[0].firstChild.data : false;
	this.channel.textInput.name = (getChildrenByTagName(RSSChannel, 'textInput')[0]) ? getChildrenByTagName(RSSTextInput, 'name')[0].firstChild.data : false;

	// Dublin Core
	this.channel.textInput.dcContributor = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'contributor')[0]) ? getChildrenByTagName(RSSTextInput, 'contributor')[0].firstChild.data : false;
	this.channel.textInput.dcCoverage = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'coverage')[0]) ? getChildrenByTagName(RSSTextInput, 'coverage')[0].firstChild.data : false;
	this.channel.textInput.dcCreator = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'creator')[0]) ? getChildrenByTagName(RSSTextInput, 'creator')[0].firstChild.data : false;
	this.channel.textInput.dcDate = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'date')[0]) ? getChildrenByTagName(RSSTextInput, 'date')[0].firstChild.data : false;
	this.channel.textInput.dcDescription = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'description')[0]) ? getChildrenByTagName(RSSTextInput, 'description')[0].firstChild.data : false;
	this.channel.textInput.dcFormat = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'format')[0]) ? getChildrenByTagName(RSSTextInput, 'format')[0].firstChild.data : false;
	this.channel.textInput.dcIdentifier = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'identifier')[0]) ? getChildrenByTagName(RSSTextInput, 'identifier')[0].firstChild.data : false;
	this.channel.textInput.dcLanguage = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'language')[0]) ? getChildrenByTagName(RSSTextInput, 'language')[0].firstChild.data : false;
	this.channel.textInput.dcPublisher = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'publisher')[0]) ? getChildrenByTagName(RSSTextInput, 'publisher')[0].firstChild.data : false;
	this.channel.textInput.dcRelation = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'relation')[0]) ? getChildrenByTagName(RSSTextInput, 'relation')[0].firstChild.data : false;
	this.channel.textInput.dcRights = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'rights')[0]) ? getChildrenByTagName(RSSTextInput, 'rights')[0].firstChild.data : false;
	this.channel.textInput.dcSource = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'source')[0]) ? getChildrenByTagName(RSSTextInput, 'source')[0].firstChild.data : false;
	this.channel.textInput.dcSubject = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'subject')[0]) ? getChildrenByTagName(RSSTextInput, 'subject')[0].firstChild.data : false;
	this.channel.textInput.dcTitle = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'title')[0]) ? getChildrenByTagName(RSSTextInput, 'title')[0].firstChild.data : false;
	this.channel.textInput.dcType = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'type')[0]) ? getChildrenByTagName(RSSTextInput, 'type')[0].firstChild.data : false;
	*/

	// <item>, required tag set.  Multiple are allowed, so make them all parsable.
	this.channel.item = new Array();
	for (var x=0; x<getChildrenByTagName(RSSChannel, 'item').length; x++) {
	    this.channel.item[x] = getChildrenByTagName(RSSChannel, 'item')[x];
	}

	for (var y=0; y<this.channel.item.length; y++) {
	    var RSSItem = (getChildrenByTagName(RSSChannel, 'item')[y]) ? getChildrenByTagName(RSSChannel, 'item')[y] : false;
	    this.channel.item[y] = new Object();
	    this.channel.item[y].author = (getChildrenByTagName(RSSItem, 'author')[0]) ? getChildrenByTagName(RSSItem, 'author')[0].firstChild.data : false;

	    this.channel.item[y].category = (getChildrenByTagName(RSSItem, 'category')[0]) ? getChildrenByTagName(RSSItem, 'category')[0].firstChild.data : false;
	    // Since this attribute is optional, we will first check if the element exists, and if so, check if the attribute exists.
	    /*
	    this.channel.item[y].category_domain = (!getChildrenByTagName(RSSItem, 'category')[0]) ? false: (getChildrenByTagName(RSSItem, 'category')[0].getAttribute('domain')) ? getChildrenByTagName(RSSItem, 'category')[0].getAttribute('domain') : false;

	    this.channel.item[y].comments = (getChildrenByTagName(RSSItem, 'comments')[0]) ? getChildrenByTagName(RSSItem, 'comments')[0].firstChild.data : false;
	    */
	    this.channel.item[y].description = (getChildrenByTagName(RSSItem, 'description')[0]) ? getChildrenByTagName(RSSItem, 'description')[0].firstChild.data : false;

	    /*
	    this.channel.item[y].enclosure = (getChildrenByTagName(RSSItem, 'enclosure')[0]) ? getChildrenByTagName(RSSItem, 'enclosure')[0].firstChild.data : false;
	    // Since these attributes are required if <enclosure> is used, we will only check if <enclosure> exists.
	    this.channel.item[y].enclosure_length = (getChildrenByTagName(RSSItem, 'enclosure')[0]) ? getChildrenByTagName(RSSItem, 'enclosure')[0].getAttribute('length') : false;
	    this.channel.item[y].enclosure_type = (getChildrenByTagName(RSSItem, 'enclosure')[0]) ? getChildrenByTagName(RSSItem, 'enclosure')[0].getAttribute('type') : false;
	    this.channel.item[y].enclosure_url = (getChildrenByTagName(RSSItem, 'enclosure')[0]) ? getChildrenByTagName(RSSItem, 'enclosure')[0].getAttribute('url') : false;

	    this.channel.item[y].guid = (getChildrenByTagName(RSSItem, 'guid')[0]) ? getChildrenByTagName(RSSItem, 'guid')[0].firstChild.data : false;
	    // Since this attribute is optional, we will first check if the element exists, and if so, check if the attribute exists.
	    this.channel.item[y].guid_isPermaLink = (!getChildrenByTagName(RSSItem, 'guid')[0]) ? false: (getChildrenByTagName(RSSItem, 'guid')[0].getAttribute('isPermaLink')) ? getChildrenByTagName(RSSItem, 'guid')[0].getAttribute('isPermaLink') : false;
	    */

	    this.channel.item[y].link = (getChildrenByTagName(RSSItem, 'link')[0]) ? getChildrenByTagName(RSSItem, 'link')[0].firstChild.data : false;
	    this.channel.item[y].pubDate = (getChildrenByTagName(RSSItem, 'pubDate')[0]) ? getChildrenByTagName(RSSItem, 'pubDate')[0].firstChild.data : false;

	    /*
	    this.channel.item[y].source = (getChildrenByTagName(RSSItem, 'source')[0]) ? getChildrenByTagName(RSSItem, 'source')[0].firstChild.data : false;
	    // Since this attribute is required if <source> is used, we will only check if <source> exists.
	    this.channel.item[y].source_url = (getChildrenByTagName(RSSItem, 'source')[0]) ? getChildrenByTagName(RSSItem, 'source')[0].getAttribute('url') : false;
	    */

	    this.channel.item[y].title = (getChildrenByTagName(RSSItem, 'title')[0]) ? getChildrenByTagName(RSSItem, 'title')[0].firstChild.data : false;

	    // Dublin Core
	    /*
	    this.channel.item[y].dcContributor = (RSSItem && getChildrenByTagName(RSSItem, 'contributor')[0]) ? getChildrenByTagName(RSSItem, 'contributor')[0].firstChild.data : false;
	    this.channel.item[y].dcCoverage = (RSSItem && getChildrenByTagName(RSSItem, 'coverage')[0]) ? getChildrenByTagName(RSSItem, 'coverage')[0].firstChild.data : false;
	    this.channel.item[y].dcCreator = (RSSItem && getChildrenByTagName(RSSItem, 'creator')[0]) ? getChildrenByTagName(RSSItem, 'creator')[0].firstChild.data : false;
	    this.channel.item[y].dcDate = (RSSItem && getChildrenByTagName(RSSItem, 'date')[0]) ? getChildrenByTagName(RSSItem, 'date')[0].firstChild.data : false;
	    this.channel.item[y].dcDescription = (RSSItem && getChildrenByTagName(RSSItem, 'description')[0]) ? getChildrenByTagName(RSSItem, 'description')[0].firstChild.data : false;
	    this.channel.item[y].dcFormat = (RSSItem && getChildrenByTagName(RSSItem, 'format')[0]) ? getChildrenByTagName(RSSItem, 'format')[0].firstChild.data : false;
	    this.channel.item[y].dcIdentifier = (RSSItem && getChildrenByTagName(RSSItem, 'identifier')[0]) ? getChildrenByTagName(RSSItem, 'identifier')[0].firstChild.data : false;
	    this.channel.item[y].dcLanguage = (RSSItem && getChildrenByTagName(RSSItem, 'language')[0]) ? getChildrenByTagName(RSSItem, 'language')[0].firstChild.data : false;
	    this.channel.item[y].dcPublisher = (RSSItem && getChildrenByTagName(RSSItem, 'publisher')[0]) ? getChildrenByTagName(RSSItem, 'publisher')[0].firstChild.data : false;
	    this.channel.item[y].dcRelation = (RSSItem && getChildrenByTagName(RSSItem, 'relation')[0]) ? getChildrenByTagName(RSSItem, 'relation')[0].firstChild.data : false;
	    this.channel.item[y].dcRights = (RSSItem && getChildrenByTagName(RSSItem, 'rights')[0]) ? getChildrenByTagName(RSSItem, 'rights')[0].firstChild.data : false;
	    this.channel.item[y].dcSource = (RSSItem && getChildrenByTagName(RSSItem, 'source')[0]) ? getChildrenByTagName(RSSItem, 'source')[0].firstChild.data : false;
	    this.channel.item[y].dcSubject = (RSSItem && getChildrenByTagName(RSSItem, 'subject')[0]) ? getChildrenByTagName(RSSItem, 'subject')[0].firstChild.data : false;
	    this.channel.item[y].dcTitle = (RSSItem && getChildrenByTagName(RSSItem, 'title')[0]) ? getChildrenByTagName(RSSItem, 'title')[0].firstChild.data : false;
	    this.channel.item[y].dcType = (RSSItem && getChildrenByTagName(RSSItem, 'type')[0]) ? getChildrenByTagName(RSSItem, 'type')[0].firstChild.data : false;

	    // Creative Commons <license> tag
	    this.channel.item[y].ccLicense = (RSSItem && getChildrenByTagName(RSSItem, 'license')[0]) ? getChildrenByTagName(RSSItem, 'license')[0].firstChild.data : false;
	    */
	}
    } else if (this.typeRDF) {
	/*******************************************************
	Begin parsing the RSS 1.0 (RDF) specification.
	*******************************************************/
	// Master RDF Element
	var RDFElem = xmlFeed.getElementsByTagName('RDF')[0];

	// Channel
	var RSSChannel = getChildrenByTagName(RDFElem, 'channel')[0]
	this.channel = new Object();
	this.readTag = RDFElem;
	// Since this attribute is required if <channel> is used, we will only check if <channel> exists.
	this.channel_rdfAbout = (getChildrenByTagName(RDFElem, 'channel')[0]) ? getChildrenByTagName(RDFElem, 'channel')[0].getAttributeNS(this.nsRDF, 'about') : false;

	// Required tags.  Parsing will fail without these.
	this.channel.title = getChildrenByTagName(RSSChannel, 'title')[0].firstChild.data;
	this.channel.link = getChildrenByTagName(RSSChannel, 'link')[0].firstChild.data;
	try {
	    this.channel.description = getChildrenByTagName(RSSChannel, 'description')[0].firstChild.data;
	} catch (e) {
	    this.channel.description = 'No description available';
	}

	// Creative Commons <license> tag
	this.channel.ccLicense = (getChildrenByTagName(RSSChannel, 'license')[0]) ? getChildrenByTagName(RSSChannel, 'license')[0] : false;
	// Since this attribute is required if <cc:license> is used, we will only check if <cc:license> exists.
	this.channel.ccLicense_rdfResource = (getChildrenByTagName(RSSChannel, 'license')[0]) ? getChildrenByTagName(RSSChannel, 'license')[0].getAttributeNS(this.nsCC, 'resource') : false;

	// Optional Tags
	/*
	this.channel.image = (getChildrenByTagName(RSSChannel, 'image')[0]) ? getChildrenByTagName(RSSChannel, 'image')[0] : false;
	// Since this attribute is required if <image> is used, we will only check if <image> exists.
	this.channel.image_rdfResource = (getChildrenByTagName(RSSChannel, 'image')[0]) ? getChildrenByTagName(RSSChannel, 'image')[0].getAttributeNS(this.nsRDF, 'resource') : false;

	this.channel.textInput = (getChildrenByTagName(RSSChannel, 'textinput')[0]) ? getChildrenByTagName(RSSChannel, 'textinput')[0] : false;
	// Since this attribute is required if <textinput> is used, we will only check if <textinput> exists.
	this.channel.textInput_rdfResource = (getChildrenByTagName(RSSChannel, 'textinput')[0]) ? getChildrenByTagName(RSSChannel, 'textinput')[0].getAttributeNS(this.nsRDF, 'resource') : false;
	*/

	// <items> (note the "s").
	var RSSItems = (getChildrenByTagName(RSSChannel, 'items')[0]) ? getChildrenByTagName(RSSChannel, 'items')[0] : false;
	this.channel.items = new Object();
	var RDFSeq = (RSSItems) ? RSSItems.getElementsByTagNameNS(this.nsRDF, 'Seq')[0] : false;
	var RDFSeqLi = (RDFSeq) ? RDFSeq.getElementsByTagNameNS(this.nsRDF, 'li') : false;
	this.channel.items.rdfSeq = new Object();

	// <rdf:li>, required tag set.  Multiple are allowed, so make them all parsable.
	this.channel.items.rdfSeq.li = new Array();
	this.channel.items.rdfSeq.li_rdfResource = new Array();
	for (var x=0; x<RDFSeqLi.length; x++) {
	    this.channel.items.rdfSeq.li[x] = RDFSeqLi[x];
	    this.channel.items.rdfSeq.li_rdfResource[x] = RDFSeqLi[x].getAttributeNS(this.nsRDF, 'resource');
	}

	// <image>
	/*
	var RSSImage = (getChildrenByTagName(RDFElem, 'image')[0]) ? getChildrenByTagName(RDFElem, 'image')[0] : false;
	this.image = new Object();
	// Since this attribute is required if <image> is used, we will only check if <image> exists.
	this.image_rdfAbout = (getChildrenByTagName(RDFElem, 'image')[0]) ? getChildrenByTagName(RDFElem, 'image')[0].getAttributeNS(this.nsRDF, 'about') : false;

	// Required tags.  Parsing will fail without these.
	this.image.title = (RSSImage && getChildrenByTagName(RSSImage, 'title')[0]) ? getChildrenByTagName(RSSImage, 'title')[0].firstChild.data : false;
	this.image.url = (RSSImage && getChildrenByTagName(RSSImage, 'url')[0]) ? getChildrenByTagName(RSSImage, 'url')[0].firstChild.data : false;
	this.image.link = (RSSImage && getChildrenByTagName(RSSImage, 'link')[0]) ? getChildrenByTagName(RSSImage, 'link')[0].firstChild.data : false;
	*/

	// Dublin Core
	/*
	this.image.dcContributor = (RSSImage && getChildrenByTagName(RSSImage, 'contributor')[0]) ? getChildrenByTagName(RSSImage, 'contributor')[0].firstChild.data : false;
	this.image.dcCoverage = (RSSImage && getChildrenByTagName(RSSImage, 'coverage')[0]) ? getChildrenByTagName(RSSImage, 'coverage')[0].firstChild.data : false;
	this.image.dcCreator = (RSSImage && getChildrenByTagName(RSSImage, 'creator')[0]) ? getChildrenByTagName(RSSImage, 'creator')[0].firstChild.data : false;
	this.image.dcDate = (RSSImage && getChildrenByTagName(RSSImage, 'date')[0]) ? getChildrenByTagName(RSSImage, 'date')[0].firstChild.data : false;
	this.image.dcDescription = (RSSImage && getChildrenByTagName(RSSImage, 'description')[0]) ? getChildrenByTagName(RSSImage, 'description')[0].firstChild.data : false;
	this.image.dcFormat = (RSSImage && getChildrenByTagName(RSSImage, 'format')[0]) ? getChildrenByTagName(RSSImage, 'format')[0].firstChild.data : false;
	this.image.dcIdentifier = (RSSImage && getChildrenByTagName(RSSImage, 'identifier')[0]) ? getChildrenByTagName(RSSImage, 'identifier')[0].firstChild.data : false;
	this.image.dcLanguage = (RSSImage && getChildrenByTagName(RSSImage, 'language')[0]) ? getChildrenByTagName(RSSImage, 'language')[0].firstChild.data : false;
	this.image.dcPublisher = (RSSImage && getChildrenByTagName(RSSImage, 'publisher')[0]) ? getChildrenByTagName(RSSImage, 'publisher')[0].firstChild.data : false;
	this.image.dcRelation = (RSSImage && getChildrenByTagName(RSSImage, 'relation')[0]) ? getChildrenByTagName(RSSImage, 'relation')[0].firstChild.data : false;
	this.image.dcRights = (RSSImage && getChildrenByTagName(RSSImage, 'rights')[0]) ? getChildrenByTagName(RSSImage, 'rights')[0].firstChild.data : false;
	this.image.dcSource = (RSSImage && getChildrenByTagName(RSSImage, 'source')[0]) ? getChildrenByTagName(RSSImage, 'source')[0].firstChild.data : false;
	this.image.dcSubject = (RSSImage && getChildrenByTagName(RSSImage, 'subject')[0]) ? getChildrenByTagName(RSSImage, 'subject')[0].firstChild.data : false;
	this.image.dcTitle = (RSSImage && getChildrenByTagName(RSSImage, 'title')[0]) ? getChildrenByTagName(RSSImage, 'title')[0].firstChild.data : false;
	this.image.dcType = (RSSImage && getChildrenByTagName(RSSImage, 'type')[0]) ? getChildrenByTagName(RSSImage, 'type')[0].firstChild.data : false;
	*/

	// Creative Commons <license> tag
	// this.image.ccLicense = (RSSImage && getChildrenByTagName(RSSImage, 'license')[0]) ? getChildrenByTagName(RSSImage, 'license')[0] : false;
	// Since this attribute is required if <cc:license> is used, we will only check if <cc:license> exists.
	// this.image.ccLicense_rdfResource = (RSSImage && getChildrenByTagName(RSSImage, 'license')[0]) ? getChildrenByTagName(RSSImage, 'license')[0].getAttributeNS(this.nsCC, 'resource') : false;

	// <item>, required tag set.  Multiple are allowed, so make them all parsable.
	this.item = new Array();
	this.item_rdfAbout = new Array();
	for (var x=0; x<getChildrenByTagName(RDFElem, 'item').length; x++) {
	    this.item[x] = getChildrenByTagName(RDFElem, 'item')[x];
	    this.item_rdfAbout[x] = getChildrenByTagName(RDFElem, 'item')[x].getAttributeNS(this.nsRDF, 'about');
	}

	for (var y=0; y<this.item.length; y++) {
	    var RSSItem = (getChildrenByTagName(RDFElem, 'item')[y]) ? getChildrenByTagName(RDFElem, 'item')[y] : false;
	    this.item[y] = new Object();

	    this.item[y].description = (getChildrenByTagName(RSSItem, 'description')[0]) ? getChildrenByTagName(RSSItem, 'description')[0].firstChild.data : false;
	    this.item[y].link = (getChildrenByTagName(RSSItem, 'link')[0]) ? getChildrenByTagName(RSSItem, 'link')[0].firstChild.data : false;
	    this.item[y].title = (getChildrenByTagName(RSSItem, 'title')[0]) ? getChildrenByTagName(RSSItem, 'title')[0].firstChild.data : false;

	    // Dublin Core
	    /*
	    this.item[y].dcContributor = (RSSItem && getChildrenByTagName(RSSItem, 'contributor')[0]) ? getChildrenByTagName(RSSItem, 'contributor')[0].firstChild.data : false;
	    this.item[y].dcCoverage = (RSSItem && getChildrenByTagName(RSSItem, 'coverage')[0]) ? getChildrenByTagName(RSSItem, 'coverage')[0].firstChild.data : false;
	    this.item[y].dcCreator = (RSSItem && getChildrenByTagName(RSSItem, 'creator')[0]) ? getChildrenByTagName(RSSItem, 'creator')[0].firstChild.data : false;
	    this.item[y].dcDate = (RSSItem && getChildrenByTagName(RSSItem, 'date')[0]) ? getChildrenByTagName(RSSItem, 'date')[0].firstChild.data : false;
	    this.item[y].dcDescription = (RSSItem && getChildrenByTagName(RSSItem, 'description')[0]) ? getChildrenByTagName(RSSItem, 'description')[0].firstChild.data : false;
	    this.item[y].dcFormat = (RSSItem && getChildrenByTagName(RSSItem, 'format')[0]) ? getChildrenByTagName(RSSItem, 'format')[0].firstChild.data : false;
	    this.item[y].dcIdentifier = (RSSItem && getChildrenByTagName(RSSItem, 'identifier')[0]) ? getChildrenByTagName(RSSItem, 'identifier')[0].firstChild.data : false;
	    this.item[y].dcLanguage = (RSSItem && getChildrenByTagName(RSSItem, 'language')[0]) ? getChildrenByTagName(RSSItem, 'language')[0].firstChild.data : false;
	    this.item[y].dcPublisher = (RSSItem && getChildrenByTagName(RSSItem, 'publisher')[0]) ? getChildrenByTagName(RSSItem, 'publisher')[0].firstChild.data : false;
	    this.item[y].dcRelation = (RSSItem && getChildrenByTagName(RSSItem, 'relation')[0]) ? getChildrenByTagName(RSSItem, 'relation')[0].firstChild.data : false;
	    this.item[y].dcRights = (RSSItem && getChildrenByTagName(RSSItem, 'rights')[0]) ? getChildrenByTagName(RSSItem, 'rights')[0].firstChild.data : false;
	    this.item[y].dcSource = (RSSItem && getChildrenByTagName(RSSItem, 'source')[0]) ? getChildrenByTagName(RSSItem, 'source')[0].firstChild.data : false;
	    this.item[y].dcSubject = (RSSItem && getChildrenByTagName(RSSItem, 'subject')[0]) ? getChildrenByTagName(RSSItem, 'subject')[0].firstChild.data : false;
	    this.item[y].dcTitle = (RSSItem && getChildrenByTagName(RSSItem, 'title')[0]) ? getChildrenByTagName(RSSItem, 'title')[0].firstChild.data : false;
	    this.item[y].dcType = (RSSItem && getChildrenByTagName(RSSItem, 'type')[0]) ? getChildrenByTagName(RSSItem, 'type')[0].firstChild.data : false;

	    // Creative Commons <license> tag
	    this.item[y].ccLicense = (getChildrenByTagName(RSSItem, 'license')[0]) ? getChildrenByTagName(RSSItem, 'license')[0] : false;
	    // Since this attribute is required if <cc:license> is used, we will only check if <cc:license> exists.
	    this.item[y].ccLicense_rdfResource = (getChildrenByTagName(RSSItem, 'license')[0]) ? getChildrenByTagName(RSSItem, 'license')[0].getAttributeNS(this.nsCC, 'resource') : false;
	    */
	}

	// <textinput>
	/*
	var RSSTextInput = (getChildrenByTagName(RDFElem, 'textinput')[0]) ? getChildrenByTagName(RDFElem, 'textinput')[0] : false;
	this.textInput = new Object();
	// Since this attribute is required if <textinput> is used, we will only check if <textinput> exists.
	this.textInput_rdfAbout = (getChildrenByTagName(RDFElem, 'textinput')[0]) ? getChildrenByTagName(RDFElem, 'textinput')[0].getAttributeNS(this.nsRDF, 'about') : false;

	// Required tags.  Parsing will fail without these.
	this.textInput.title = (RSSTextInput) ? getChildrenByTagName(RSSTextInput, 'title')[0].firstChild.data : false;
	try {
	    this.textInput.description = (RSSTextInput) ? getChildrenByTagName(RSSTextInput, 'description')[0].firstChild.data : false;
	} catch (e) {
	    this.textInput.description = false;
	}
	this.textInput.link = (RSSTextInput) ? getChildrenByTagName(RSSTextInput, 'link')[0].firstChild.data : false;
	this.textInput.name = (RSSTextInput) ? getChildrenByTagName(RSSTextInput, 'name')[0].firstChild.data : false;

	// Dublin Core
	this.textInput.dcContributor = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'contributor')[0]) ? getChildrenByTagName(RSSTextInput, 'contributor')[0].firstChild.data : false;
	this.textInput.dcCoverage = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'coverage')[0]) ? getChildrenByTagName(RSSTextInput, 'coverage')[0].firstChild.data : false;
	this.textInput.dcCreator = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'creator')[0]) ? getChildrenByTagName(RSSTextInput, 'creator')[0].firstChild.data : false;
	this.textInput.dcDate = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'date')[0]) ? getChildrenByTagName(RSSTextInput, 'date')[0].firstChild.data : false;
	this.textInput.dcDescription = (RSSTextInput && this.textInput.description) ? getChildrenByTagName(RSSTextInput, 'description')[0].firstChild.data : false;
	this.textInput.dcFormat = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'format')[0]) ? getChildrenByTagName(RSSTextInput, 'format')[0].firstChild.data : false;
	this.textInput.dcIdentifier = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'identifier')[0]) ? getChildrenByTagName(RSSTextInput, 'identifier')[0].firstChild.data : false;
	this.textInput.dcLanguage = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'language')[0]) ? getChildrenByTagName(RSSTextInput, 'language')[0].firstChild.data : false;
	this.textInput.dcPublisher = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'publisher')[0]) ? getChildrenByTagName(RSSTextInput, 'publisher')[0].firstChild.data : false;
	this.textInput.dcRelation = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'relation')[0]) ? getChildrenByTagName(RSSTextInput, 'relation')[0].firstChild.data : false;
	this.textInput.dcRights = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'rights')[0]) ? getChildrenByTagName(RSSTextInput, 'rights')[0].firstChild.data : false;
	this.textInput.dcSource = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'source')[0]) ? getChildrenByTagName(RSSTextInput, 'source')[0].firstChild.data : false;
	this.textInput.dcSubject = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'subject')[0]) ? getChildrenByTagName(RSSTextInput, 'subject')[0].firstChild.data : false;
	this.textInput.dcTitle = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'title')[0]) ? getChildrenByTagName(RSSTextInput, 'title')[0].firstChild.data : false;
	this.textInput.dcType = (RSSTextInput && getChildrenByTagName(RSSTextInput, 'type')[0]) ? getChildrenByTagName(RSSTextInput, 'type')[0].firstChild.data : false;
	*/
    } else if (this.typeAtom) {
	/*******************************************************
	Begin parsing the Atom 0.3 specification.
	*******************************************************/
	// Master Feed Element
	var feedElem = xmlFeed.getElementsByTagName('feed')[0];
	this.xmlLang = feedElem.getAttribute('xml:lang');

	// Read any tag...
	this.readTag = feedElem;

	this.author = new Object();
	var feedAuthor = getChildrenByTagName(feedElem, 'author')[0];
	this.author.email = (feedAuthor && getChildrenByTagName(feedAuthor, 'email')[0]) ? getChildrenByTagName(feedAuthor, 'email')[0].firstChild.data : false;
	this.author.name = (feedAuthor && getChildrenByTagName(feedAuthor, 'name')[0]) ? getChildrenByTagName(feedAuthor, 'name')[0].firstChild.data : false;
	this.author.url = (feedAuthor && getChildrenByTagName(feedAuthor, 'url')[0]) ? getChildrenByTagName(feedAuthor, 'url')[0].firstChild.data : false;
	// this.contributor = (getChildrenByTagName(feedElem, 'contributor')[0]) ? getChildrenByTagName(feedElem, 'contributor')[0].firstChild.data : false;
	this.copyright = (getChildrenByTagName(feedElem, 'copyright')[0]) ? getChildrenByTagName(feedElem, 'copyright')[0].firstChild.data : false;
	// this.id = (getChildrenByTagName(feedElem, 'id')[0]) ? getChildrenByTagName(feedElem, 'id')[0].firstChild.data : false;
	this.info = (getChildrenByTagName(feedElem, 'info')[0]) ? getChildrenByTagName(feedElem, 'info')[0].firstChild.data : false;
	// this.modified = getChildrenByTagName(feedElem, 'modified')[0].firstChild.data;
	try {
	    this.tagline = getChildrenByTagName(feedElem, 'tagline')[0].firstChild.data;
	} catch (e) {
	    this.tagline = '';
	}
	this.title = getChildrenByTagName(feedElem, 'title')[0].firstChild.data;

	this.generator = (getChildrenByTagName(feedElem, 'generator')[0]) ? getChildrenByTagName(feedElem, 'generator')[0].firstChild.data : false;
	this.generator_url = (this.generator && getChildrenByTagName(feedElem, 'generator')[0].getAttribute('url')) ? getChildrenByTagName(feedElem, 'generator')[0].getAttribute('url') : false; // Optional
	this.generator_version = (this.generator && getChildrenByTagName(feedElem, 'generator')[0].getAttribute('version')) ? getChildrenByTagName(feedElem, 'generator')[0].getAttribute('version') : false; // Optional

	this.link = getChildrenByTagName(feedElem, 'link')[0];
	this.link_href = this.link.getAttribute('href'); // Required
	this.link_rel = this.link.getAttribute('rel'); // Required
	this.link_title = (this.link.getAttribute('title')) ? this.link.getAttribute('title') : false; // Optional
	this.link_type = (this.link.getAttribute('type')) ? this.link.getAttribute('type') : false; // Optional

	// <entry> -- Multiple are allowed, so make them all parsable.
	this.entry = new Array();
	for (var x=0; x<getChildrenByTagName(feedElem, 'entry').length; x++) {
	    this.entry[x] = getChildrenByTagName(feedElem, 'entry')[x];
	}

	for (var y=0; y<this.entry.length; y++) {
	    var feedEntry = (getChildrenByTagName(feedElem, 'entry')[y]) ? getChildrenByTagName(feedElem, 'entry')[y] : false;
	    this.entry[y] = new Object();

	    this.entry[y].contributor = (getChildrenByTagName(feedEntry, 'contributor')[0]) ? getChildrenByTagName(feedEntry, 'contributor')[0].firstChild.data : false;
	    this.entry[y].created = (getChildrenByTagName(feedEntry, 'created')[0]) ? getChildrenByTagName(feedEntry, 'created')[0].firstChild.data : false;
	    this.entry[y].id = (getChildrenByTagName(feedEntry, 'id')[0]) ? getChildrenByTagName(feedEntry, 'id')[0].firstChild.data : false;
	    this.entry[y].issued = getChildrenByTagName(feedEntry, 'issued')[0].firstChild.data;
	    this.entry[y].modified = getChildrenByTagName(feedEntry, 'modified')[0].firstChild.data;
	    this.entry[y].title = (getChildrenByTagName(feedEntry, 'title')[0]) ? getChildrenByTagName(feedEntry, 'title')[0].firstChild.data : false;

	    this.entry[y].author = new Object();
	    var entryAuthor = getChildrenByTagName(feedEntry, 'author')[0];
	    this.entry[y].author.email = (entryAuthor && getChildrenByTagName(entryAuthor, 'email')[0]) ? getChildrenByTagName(entryAuthor, 'email')[0].firstChild.data : false;
	    this.entry[y].author.name = (entryAuthor && getChildrenByTagName(entryAuthor, 'name')[0]) ? getChildrenByTagName(entryAuthor, 'name')[0].firstChild.data : false;
	    this.entry[y].author.url = (entryAuthor && getChildrenByTagName(entryAuthor, 'url')[0]) ? getChildrenByTagName(entryAuthor, 'url')[0].firstChild.data : false;

	    this.entry[y].content = (getChildrenByTagName(feedEntry, 'content')[0]) ? getChildrenByTagName(feedEntry, 'content')[0].firstChild.nodeValue : false;
	    this.entry[y].content_mode = (getChildrenByTagName(feedEntry, 'content')[0].getAttribute('mode')) ? getChildrenByTagName(feedEntry, 'content')[0].getAttribute('mode') : false;
	    this.entry[y].content_type = (getChildrenByTagName(feedEntry, 'content')[0].getAttribute('type')) ? getChildrenByTagName(feedEntry, 'content')[0].getAttribute('type') : false;
	    this.entry[y].content_xmlBase = (getChildrenByTagName(feedEntry, 'content')[0].getAttribute('xml:base')) ? getChildrenByTagName(feedEntry, 'content')[0].getAttribute('xml:base') : false;
	    this.entry[y].content_xmlLang = (getChildrenByTagName(feedEntry, 'content')[0].getAttribute('xml:lang')) ? getChildrenByTagName(feedEntry, 'content')[0].getAttribute('xml:lang') : false;

	    this.entry[y].link = getChildrenByTagName(feedEntry, 'link')[0];
	    this.entry[y].link_href = this.entry[y].link.getAttribute('href'); // Required
	    this.entry[y].link_rel = this.entry[y].link.getAttribute('rel'); // Required
	    this.entry[y].link_title = (this.entry[y].link.getAttribute('title')) ? this.link.getAttribute('title') : false; // Optional
	    this.entry[y].link_type = (this.entry[y].link.getAttribute('type')) ? this.link.getAttribute('type') : false; // Optional

	    this.entry[y].summary = (getChildrenByTagName(feedEntry, 'summary')[0]) ? getChildrenByTagName(feedEntry, 'summary')[0].firstChild.data : false;
	    this.entry[y].summary_type = (getChildrenByTagName(feedEntry, 'summary')[0].getAttribute('type')) ? getChildrenByTagName(feedEntry, 'summary')[0].getAttribute('type') : false; // Spec didn't make this clear, so I'm leaving it as optional for now.
	}
    }


    /*******************************************************
    Begin parsing the RSS 1.0 Syndication Module.
    Allowed in <channel> element.
    *******************************************************/
    if (this.typeRSS || this.typeRDF) {
	var SYChannel = getChildrenByTagName(MasterElem, 'channel')[0];
	this.channel.syUpdateBase = (getChildrenByTagName(SYChannel, 'updateBase')[0]) ? getChildrenByTagName(SYChannel, 'updateBase')[0].firstChild.data : false;
	this.channel.syUpdateFrequency = (getChildrenByTagName(SYChannel, 'updateFrequency')[0]) ? getChildrenByTagName(SYChannel, 'updateFrequency')[0].firstChild.data : false;
	this.channel.syUpdatePeriod = (getChildrenByTagName(SYChannel, 'updatePeriod')[0]) ? getChildrenByTagName(SYChannel, 'updatePeriod')[0].firstChild.data : false;
    }


    /*******************************************************
    Begin parsing the RSS 1.0 Dublin Core Metadata Element Set.
    Allowed in <channel>, <item>, <image>, and <textinput> elements.
    *******************************************************/
    if (this.typeRSS || this.typeRDF) {
	var DCChannel = getChildrenByTagName(MasterElem, 'channel')[0];
	// Add parsing for immediate subelements of <channel>
	this.channel.dcContributor = (getChildrenByTagName(DCChannel, 'contributor')[0]) ? getChildrenByTagName(DCChannel, 'contributor')[0].firstChild.data : false;
	this.channel.dcCoverage = (getChildrenByTagName(DCChannel, 'coverage')[0]) ? getChildrenByTagName(DCChannel, 'coverage')[0].firstChild.data : false;
	this.channel.dcCreator = (getChildrenByTagName(DCChannel, 'creator')[0]) ? getChildrenByTagName(DCChannel, 'creator')[0].firstChild.data : false;
	this.channel.dcDate = (getChildrenByTagName(DCChannel, 'date')[0]) ? getChildrenByTagName(DCChannel, 'date')[0].firstChild.data : false;
	try {
	    this.channel.dcDescription = (getChildrenByTagName(DCChannel, 'description')[0]) ? getChildrenByTagName(DCChannel, 'description')[0].firstChild.data : false;
	} catch (e) {
	    this.channel.dcDescription = 'No description available';
	}
	this.channel.dcFormat = (getChildrenByTagName(DCChannel, 'format')[0]) ? getChildrenByTagName(DCChannel, 'format')[0].firstChild.data : false;
	this.channel.dcIdentifier = (getChildrenByTagName(DCChannel, 'identifier')[0]) ? getChildrenByTagName(DCChannel, 'identifier')[0].firstChild.data : false;
	this.channel.dcLanguage = (getChildrenByTagName(DCChannel, 'language')[0]) ? getChildrenByTagName(DCChannel, 'language')[0].firstChild.data : false;
	this.channel.dcPublisher = (getChildrenByTagName(DCChannel, 'publisher')[0]) ? getChildrenByTagName(DCChannel, 'publisher')[0].firstChild.data : false;
	this.channel.dcRelation = (getChildrenByTagName(DCChannel, 'relation')[0]) ? getChildrenByTagName(DCChannel, 'relation')[0].firstChild.data : false;
	this.channel.dcRights = (getChildrenByTagName(DCChannel, 'rights')[0]) ? getChildrenByTagName(DCChannel, 'rights')[0].firstChild.data : false;
	this.channel.dcSource = (getChildrenByTagName(DCChannel, 'source')[0]) ? getChildrenByTagName(DCChannel, 'source')[0].firstChild.data : false;
	this.channel.dcSubject = (getChildrenByTagName(DCChannel, 'subject')[0]) ? getChildrenByTagName(DCChannel, 'subject')[0].firstChild.data : false;
	this.channel.dcTitle = (getChildrenByTagName(DCChannel, 'title')[0]) ? getChildrenByTagName(DCChannel, 'title')[0].firstChild.data : false;
	this.channel.dcType = (getChildrenByTagName(DCChannel, 'type')[0]) ? getChildrenByTagName(DCChannel, 'type')[0].firstChild.data : false;
    }
}
