/***** BEGIN LICENSE BLOCK *****
   - Version: MPL 1.1/GPL 2.0/LGPL 2.1
   -
   - The contents of this file are subject to the Mozilla Public License Version
   - 1.1 (the "License"); you may not use this file except in compliance with
   - the License. You may obtain a copy of the License at
   - http://www.mozilla.org/MPL/
   -
   - Software distributed under the License is distributed on an "AS IS" basis,
   - WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
   - for the specific language governing rights and limitations under the
   - License.
   -
   - The Original Code is _by Sudhakar "Thaths" Chandrasekharan_.
   -
   - The Initial Developer of the Original Code is
   - _Sudhakar "Thaths" Chandrasekharan <thaths@openscroll.org>_.
   - Portions created by the Initial Developer are Copyright (C) 2003-2004
   - the Initial Developer. All Rights Reserved.
   -
   - Contributor(s):
   - Sudhakar "Thaths" Chandra <thaths@openscroll.org> (original author)
   -
   - Alternatively, the contents of this file may be used under the terms of
   - either the GNU General Public License Version 2 or later (the "GPL"), or
   - the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
   - in which case the provisions of the GPL or the LGPL are applicable instead
   - of those above. If you wish to allow use of your version of this file only
   - under the terms of either the GPL or the LGPL, and not to allow others to
   - use your version of this file under the terms of the MPL, indicate your
   - decision by deleting the provisions above and replace them with the notice
   - and other provisions required by the LGPL or the GPL. If you do not delete
   - the provisions above, a recipient may use your version of this file under
   - the terms of any one of the MPL, the GPL or the LGPL.
   -
   - ***** END LICENSE BLOCK *****/

/**************************************************************************
* The following is to enable dumps from inside JS.
**************************************************************************/
var debugboolean = true;
//setting pref for debug
if(debugboolean==true)
{
    const PREFS_CID      = "@mozilla.org/preferences;1";
    const PREFS_I_PREF   = "nsIPref";
    const PREF_STRING    = "browser.dom.window.dump.enabled";
    try {
	var Pref        = new Components.Constructor(PREFS_CID, PREFS_I_PREF);
	var pref        = new Pref( );
	pref.SetBoolPref(PREF_STRING, true);
    } catch(e) { 
	alert(e);
    }
}

// Some XPCOM constants we need to walk the bookmarks tree
// Commented out because they are already defined in chrome://communicator/content/bookmarks/bookmarks.js
// const RDF = Components.classes['@mozilla.org/rdf/rdf-service;1'].getService(Components.interfaces.nsIRDFService);
// const RDFC = Components.classes['@mozilla.org/rdf/container;1'].createInstance(Components.interfaces.nsIRDFContainer);
// const RDFCU = Components.classes['@mozilla.org/rdf/container-utils;1'].getService(Components.interfaces.nsIRDFContainerUtils);
// const XUL_NS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
// const NC_NS = "http://home.netscape.com/NC-rdf#";
// const BMDS = Components .classes["@mozilla.org/rdf/datasource;1?name=bookmarks"].getService(Components.interfaces.nsIRDFDataSource); 
// const RDF_NS = "http://www.w3.org/1999/02/22-rdf-syntax-ns#";
const XPPREF = Components.classes["@mozilla.org/preferences;1"].getService(Components.interfaces.nsIPrefBranch);
const USER_AGENT = navigator.appCodeName + "/" + navigator.appVersion + " Habari Xenu News Aggregator 0.7.0 (http://habarixenu.mozdev.org/; thaths@mozdev.org)";

// Some global variables that are used across functions
var feedsTree;		// The tree used to display the feeds
var xmlhttp;		// A HTTP request object
var localPath;		// Path to feeds downloaded into a local file
var win;		// The Habari Xenu window
var progmtr;		// The progress meter
var updateInterval;	// How often to update
var showDetail;		// Should we show details about the feed
var fetchURL;		// The Feed's URL
var initialized = false;    // amiinitializedornot.com
var lastUpdatedAt;
var strbundle;

// HTTP request results
const RESULT_OK = 0;
const RESULT_PARSE_ERROR = 1;
const RESULT_NOT_RSS = 2;
const RESULT_NOT_FOUND = 3;
const RESULT_NOT_AVAILABLE = 4;
const RESULT_ERROR_FAILURE = 5;



/**************************************************************************
* This is a simple CSS-DOM-based toggle function
**************************************************************************/
/*
function toggleDetail() {
    var currentDisplay = document.getElementById("details").style.display;
    var newDisplay = (currentDisplay == 'inline') ? 'none' : 'inline';
    document.getElementById("details").style.display = newDisplay;
    return true;
}
*/



/**************************************************************************
* Populate the tree from the Datasource. See above for how we get 'ds'
* This function gets called on the XUL window's onload event
**************************************************************************/
function buildTreeFromDataSource() {
    dump("buildTreeFromDataSource(): Beginning to build subscription tree from bookmarks\n");

    // strbundle=document.getElementById("_stringbundle");
    strbundle=srGetStrBundle("chrome://habarixenu/locale/strings.properties");

    // Set the feedsTree to point to the tree in which feeds are stored
    feedsTree = document.getElementById("feedsTree");

    // The bookmark folder that contains bookmarks to all the RSS feeds
    var prefFolder;

    // Has user selected one folder as preferred feeds folder
    if(XPPREF.getPrefType("extensions.habarixenu.feeds_folder") == XPPREF.PREF_INVALID){
	// No preferred folder.  Set it to the top of bookmarks RDF
	dump("buildTreeFromDataSource(): No feeds folder preference.  Setting defaults.\n");
	prefFolder = "NC:BookmarksRoot";
    } else {
	// Set to the preferred folder
	prefFolder = XPPREF.getCharPref("extensions.habarixenu.feeds_folder").toString();
	dump("buildTreeFromDataSource(): Existing preference.  Setting to " + prefFolder + "\n");
    }

    if(XPPREF.getPrefType("extensions.habarixenu.update_interval") == XPPREF.PREF_INVALID){
	// No update interval.  Set it to 60 mins
	dump("buildTreeFromDataSource(): No update interval preference.  Setting defaults.\n");
	updateInterval = 60;
    } else {
	// Set to the user's preferences
	updateInterval = XPPREF.getIntPref("extensions.habarixenu.update_interval");
	dump("buildTreeFromDataSource(): Existing preference.  Update interval is " + updateInterval + "\n");
    }

    if(XPPREF.getPrefType("extensions.habarixenu.show_details") == XPPREF.PREF_INVALID){
	// No update interval.  Set it to 60 mins
	dump("buildTreeFromDataSource(): No show detail preference.  Setting defaults.\n");
	showDetail = false;
    } else {
	// Set to the user's preferences
	showDetail = XPPREF.getBoolPref("extensions.habarixenu.show_details");
	dump("buildTreeFromDataSource(): Existing preference.  Show detail is " + showDetail + "\n");
    }

    // If we don't run the following only once, it goes into a loop
    // for some reason, buildTreeFromDataSource() gets called a few times
    // when the application is loaded.  Probably because the onload event
    // on the feedsTree happens whenever the browser finishes re-painting.
    if (! initialized) {
	dump("buildTreeFromDataSource(): Not initialized.  Initializing...\n");

	// Initialize win to point to the main window
	win = document.getElementsByTagName("window")[0];
	progmtr = document.getElementById("progmtr");

	// Set the progress meter
	busy();

	// Initialize some stuff in chrome://communicator/content/bookmarks/bookmarks.js
	initServices();
	initBMService();

	// Set the ref attribute on the tree and rebuild it
	feedsTree.setAttribute("ref", prefFolder);
	feedsTree.builder.rebuild();

	// Unset the progress meter
	free();
    }

    if (initialized) {
	dump("buildTreeFromDataSource(): Already initialized.  Returning false.\n");
	return false;
    } else {
	var fu = new FileUtils();
	var aboutPath = fu.chromeToPath('chrome://habarixenu/locale/about.html');

	// Some stuff we need to do for Windows
	var plat = navigator.platform;
	dump("Platform is " + plat + "\n");
	var platRE = new RegExp("win","i");
	if(plat.search(platRE) != -1) {
	    aboutPath = unescape(aboutPath);

	    var re2 = new RegExp('^/');
	    aboutPath = aboutPath.replace(re2,'');
		
	    var re1 = new RegExp('/','g');
	    aboutPath = aboutPath.replace(re1,'\\');
	}

	var aboutFile = new File(aboutPath);

	// Open the about.html file and read all its contents in
	aboutFile.open('r');
	var aboutContent = aboutFile.read();
	aboutFile.close();

	// Write the contents into the browser element
	var tbrowser = document.getElementById("parsed-rss-feed");
	tbrowser.contentDocument.open();
	tbrowser.contentDocument.write(aboutContent);
	tbrowser.contentDocument.close();

	initialized = true;

	// prefFolder is pointing to the top of the bookmarks tree.  User has not
	// configured HX yet
	if (prefFolder == "NC:BookmarksRoot") {
	    // Ask user if she wants to configure now
	    if (confirm(strbundle.GetStringFromName("firsttimeconfirm"))) {
		openSettingsEditor();
	    }
	}

	dump("buildTreeFromDataSource(): Finished initialization.  Returning true.\n");
	return true;
    }
    dump("buildTreeFromDataSource(): Finished rebuilding subscription tree from bookmarks.\n");
}



/**************************************************************************
* This function gets called when the user selects an item in the feeds tree
* Here we find the URL and last update time of the feed.
**************************************************************************/
function fetchFeed(tEvent) {
    dump("fetchFeed(): Entered.\n");

    // A flag to indicate whether we downloaded a fresh local copy of a remote feed
    var freshDownload = false;

    // feedsTree = document.getElementById("feedsTree");
    feedsTree = tEvent.target;

    // If nothing was selected we have nothing to do
    if (feedsTree.currentIndex < 0) {
	dump(feedsTree.currentIndex + "\n");
	dump("fetchFeed(): Nothing selected.  Returning.\n");
	return false;
    }

    // If folder was selected we have nothing to do
    fetchURL = feedsTree.view.getCellText(feedsTree.currentIndex, "feedlist-url");
    if (! fetchURL) {
	dump("fetchFeed(): Folder selected.  Returning.\n");
	return false;
    }

    // Activate the progress meter to indicate work happening
    busy();

    // The URN of the bookmark item that has been selected
    var selectURN = feedsTree.builderView.getResourceAtIndex(feedsTree.currentIndex).Value;

    const rName = RDF.GetResource(WEB_NS + "LastVisitDate");
    var rSource = RDF.GetResource(selectURN);
    var node =  BMDS.GetTarget(rSource, rName, true);

    var lastVisited;
    try {
	// Get the LastVisitDate for this bookmark if it exists
	lastVisited = node.QueryInterface(Components.interfaces.nsIRDFDate).Value;
	lastVisited /= 1000;	// nsIRDFDate is in microseconds JS Date() deals with milliseconds
    } catch (e) {
	// LastVisitDate does not exist for this bookmark.  Probably a newly 
	// added bookmark?  Assume it was created just after the moment of creation
	lastVisited = new Date(1);  // One second since epoch
    }

    lastUpdatedAt = new Date(lastVisited);
    dump("fetchFeed(): Feed was last updated at " + lastUpdatedAt + "\n");

    var currentTime = new Date();
    dump("fetchFeed(): Current time is " + currentTime + "\n");

    // 1000 milliseconds in every second
    // 60 seconds in every minute
    // user wants to update every updateInterval minutes
    var oneHour = 1000 * 60 * updateInterval;

    var interval = currentTime - lastUpdatedAt;
    dump("fetchFeed(): interval since last update is " + interval + " ms\n");

    localPath = absPathToLocal(fetchURL);

    // Has it been an hour since the last update?
    if (interval > oneHour) {
	dump("fetchFeed(): Feed is stale.  Needs update.\n");
	downloadFromURL(fetchURL, localPath);
	freshDownload = true;
    } else {
	dump("fetchFeed(): Feed is supposed to be fresh.  Let us see if we have a local copy.\n");

	// Do we need to download a fresh copy from the server?
	try {
	    var localFile = new File(localPath);
	    if (localFile.exists()) {
		dump("fetchFeed(): We still have a local copy of the feed.  Going to parse it.\n")
		parseFeed(fetchURL);
	    } else {
		dump("fetchFeed(): We don't have a local copy of the feed.  Will fetch again.\n")
		downloadFromURL(fetchURL, localPath);
		freshDownload = true;
	    }
	} catch (e) {
	    dump("fetchFeed(): Error occured trying to see if local feed file " + localPath + " exists.\n");
	    dump(e + "\n");
	}
    }

    if (freshDownload) {
	// Newly downloaded feed.  Set its LastVisitDate in the BMDS
	dump("fetchFeed(): This is a newly downloaded feed.  Setting LastVisitDate in bookmarks.\n");

	var currentmicroseconds = currentTime.valueOf() * 1000;
	var newNode = RDF.GetDateLiteral(currentmicroseconds);

	if (node) {
	    // A LastVisitDate exists for this bookmark.  Change it
	    try {
		// dump("Called with " + rSource + "," + rName + "," + node + "," + newNode + "\n");
		BMDS.Change(rSource, rName, node, newNode);
		BMDS.QueryInterface(Components.interfaces.nsIRDFRemoteDataSource).Flush();
	    } catch (e) {
		dump("fetchFeed(): Error changing LastVisitDate of bookmark: " + e + "\n");
	    }
	} else {
	    // A LastVisitDate does not exist for this bookmark.  Create it
	    try {
		// dump("Called with " + rSource + "," + rName + "," + newNode + "\n");
		BMDS.Assert(rSource, rName, newNode, true);
		BMDS.QueryInterface(Components.interfaces.nsIRDFRemoteDataSource).Flush();
	    } catch (e) {
		dump("fetchFeed(): Error changing LastVisitDate of bookmark: " + e + "\n");
	    }
	}

    }

    // Reset feed.  Why?
    feed = new Object;

    dump("fetchFeed(): Finished. Exiting.\n");
    return false;   // Returning false because we want this event to bubble up
}



/**************************************************************************
* A utility function that takes a URl, converts into an md5 hash, appends
* it to a local feeds directory location and returns the resulting string
**************************************************************************/
function absPathToLocal(url) {
    dump("absPathToLocal(): Called with " + url + "\n");
    var fu = new FileUtils();
    var hash = hex_md5(url);

    var chromeFolder = fu.chromeToPath("chrome://habarixenu/content/feeds/");

    var plat = navigator.platform;
    	
    var platRE = new RegExp("win","i");
    if(plat.search(platRE) != -1) {
	chromeFolder = unescape(chromeFolder);
    
	var re2 = new RegExp('^/');
	chromeFolder = chromeFolder.replace(re2,'');
    		
	var re1 = new RegExp('/','g');
	chromeFolder = chromeFolder.replace(re1,'\\');
    }
    var fullPath = fu.append(chromeFolder, hash);
    // var fullPath = chromeFolder + hash;

    dump("absPathToLocal(): Returning " + fullPath + "\n");
    return fullPath;
}



/**************************************************************************
* A utility function to download the latest feed from a URL and store it
* locally into localPath
**************************************************************************/
function downloadFromURL(url, localPath) {
    dump("downloadFromURL(): Called with: " + url + "," + localPath + "\n");

    xmlhttp = new XMLHttpRequest();

    // On the following events run the named functions
    xmlhttp.onload = xmlhttpLoaded;
    xmlhttp.onerror = xmlhttpError;
    xmlhttp.onreadystatechange = xmlhttpReadyStateChange;

    // Initiate the request
    try {
	xmlhttp.open("GET", url, true);	// NOTE: Calling synchronously
	xmlhttp.setRequestHeader("User-Agent", USER_AGENT);
	xmlhttp.overrideMimeType("text/xml");
    } catch (e) {
	dump(e);
	xmlhttpGetResult(RESULT_ERROR_FAILURE);
    }

    try {
	xmlhttp.send(null);
    } catch (e) {
	dump(e);
	xmlhttpGetResult(RESULT_ERROR_FAILURE);
    }
}

function xmlhttpError(e) {
    alert("HTTP Error " + e);
}

function xmlhttpReadyStateChange() {
    if (xmlhttp.readyState == 2) {
	try {
	    if (xmlhttp.status == 404) {
		xmlhttpGetResult(RESULT_NOT_FOUND);
	    }
	} catch (e) {
	    xmlhttpGetResult(RESULT_NOT_AVAILABLE);
	    return;
	}
    } else if (xmlhttp.readyState == 3) {}
}

function xmlhttpLoaded(e) {
    var localFile;
    try {
	localFile = new File(localPath);
    } catch (e) {
	dump("xmlhttpLoaded(): Error initializing file: " + e + "\n");
    }

    if (! localFile.exists()) {
	try {
	    dump("xmlhttpLoaded(): " + localPath + " does not exist. Creating\n");
	    localFile.create();
	} catch (e) {
	    dump("xmlhttpLoaded(): Error creating file " + localPath + " : " + e + "\n");
	}
    }
    dump("xmlhttpLoaded(): " + localPath + " Created\n");

    try {
	dump("xmlhttpLoaded(): Trying to write to " + localPath + "\n");
	if(localFile.open('w') == 0) { 
	    dump("downloadFromURL(): Writing fetched data to " + localPath + "\n");
	    localFile.write("" + xmlhttp.responseText);
	} else {
	    dump("downloadFromURL(): Unable to write into " + localPath + "\n");
	}
    } catch (e) {
	dump("xmlhttpLoaded(): Error writing fetched data to local file\n");
    }
    localFile.close();
    xmlhttpGetResult(RESULT_OK);
}

function xmlhttpGetResult(aResultCode) {
    xmlhttp.abort();
    if (aResultCode == RESULT_OK) {
	// Everything OK.  Will do something here
	parseFeed();
    }
}



function formatURL(url, ois) {
    if (ois) {
	return "'' onlick=tbrowser.addTab(" + url + ")";
    } else {
	return "'" + url + "' target='new'";
    }
}



/**************************************************************************
* A function that takes the RSS that has been loaded into the hidden
* iframe, goes through it using the DOM and creates an HTML representation
* of the data in the RSS
**************************************************************************/
function parseFeed() {
    var feed = '';
    try {
	dump("parseFeed(): parsing " + localPath + "\n");
	feed = new FeedParser('file://' + localPath);
    } catch (e) {
	dump("parseFeed(): Error parsing feed: " + e + "\n");
    }

    var parsedContent = '';
    var openInSame;
    var target;
    var tbrowser = document.getElementById("parsed-rss-feed");

    if(XPPREF.getPrefType("habarixenu.open_in_same") == XPPREF.PREF_INVALID){
	// No update interval.  Set it to 60 mins
	dump("buildTreeFromDataSource(): No display preference.  Setting to default false.\n");
	openInSame = false;
    } else {
	// Set to the user's preferences
	openInSame = XPPREF.getBoolPref("habarixenu.open_in_same");
	dump("buildTreeFromDataSource(): Existing display preference is " + openInSame + "\n");
    }

    openInSame = false;
    target = (openInSame) ? "" : " target='_new'";

    if (feed.type) {
	if (feed.typeRDF) {
	    // RDF/RSS 1.0 Feeds
	    dump("parseFeed(): feed is RDF\n");

	    parsedContent = "<HTML><HEAD>\n";
	    var titleText = feed.channel.title;
	    var linkText = feed.channel.link;
	    var descText = feed.channel.description;
	    dump(titleText + "\n");

	    parsedContent += "<TITLE>" + strbundle.GetStringFromName("newsfrom") + titleText + "</TITLE>\n";
	    parsedContent += "<link rel='stylesheet' type='text/css' href='chrome://habarixenu/skin/display.css'>\n";
	    parsedContent += "</HEAD><BODY onload='return true;'>\n";
	    // parsedContent += "<script type='application/x-javascript' src='chrome://habarixenu/content/display.js'/>\n";

	    // TODO must figure out images
	    parsedContent += "<div class='header'>\n";
	    parsedContent += "<b class='header-title' id='header-title'><a href='" + linkText + "'>" + titleText + "</a></b><br>\n";
	    parsedContent += descText + "<br>\n";

	    if (showDetail) {
		parsedContent += "<p><div class='details' style='display: inline'>\n";
		parsedContent += "<b>" + strbundle.GetStringFromName("details") + "</b>:<br>";
		parsedContent += "<i>" + strbundle.GetStringFromName("feedurl") + "</i>: " + fetchURL + "<br>\n";
		parsedContent += "<i>" + strbundle.GetStringFromName("feedtype") + "</i>: RDF<br>\n";
		parsedContent += "<i>" + strbundle.GetStringFromName("feedlastdownloadedat") + "</i>:" + lastUpdatedAt + "<br>\n";
		parsedContent += "</div>\n";
	    }
	    // parsedContent += "<a href='' onClick='return toggleDetail()' id='detailsBtn' style='text-decoration: none; color: blue'>+</a> Details<br>\n"
	    parsedContent += "</div>\n";
	    dump("parseFeed(): title: " + titleText + "\n");
	    dump("parseFeed(): description: " + descText + "\n");

	    for (var i = 0; i < feed.item.length; i++) {
		parsedContent += "<div class='item'>\n";
		if (feed.item[i].title && feed.item[i].link) {
		    parsedContent += "<b><a href='" + feed.item[i].link + "'" + target + ">" + feed.item[i].title + "</a></b><br>\n";
		} else if (feed.item_rdfabout[i] && feed.item[i].title) {
		    parsedContent += "<b><a href='" + feed.item_rdfabout[i] + "'" + target + "'>" + feed.item[i].title + "</a></b><br>\n";
		} else {
		    parsedContent += "<b><a href='" + feed.item[i].link + "'" + target + ">" + feed.item[i].link + "</a></b><br>\n";
		}

		if (feed.item[i].description) {
		    parsedContent += feed.item[i].description;
		}
		parsedContent += "</div>\n";
	    }
	} else if (feed.typeRSS) {
	    // RDF/RSS 1.0 Feeds
	    dump("parseFeed(): feed is RSS\n");

	    parsedContent = "<HTML><HEAD>\n";
	    var titleText = feed.channel.title;
	    var linkText = feed.channel.link;
	    var descText = feed.channel.description;
	    dump(titleText + "\n");

	    parsedContent += "<TITLE>" + strbundle.GetStringFromName("newsfrom") + titleText + "</TITLE>\n";
	    parsedContent += "<link rel='stylesheet' type='text/css' href='chrome://habarixenu/skin/display.css'>\n";
	    parsedContent += "</HEAD><BODY onload='return true;'>\n";
	    // parsedContent += "<script type='application/x-javascript' src='chrome://habarixenu/content/display.js'/>\n";

	    // TODO must figure out images
	    parsedContent += "<div class='header'>\n";
	    parsedContent += "<b class='header-title' id='header-title'><a href='" + linkText + "'" + target + ">" + titleText + "</a></b><br>\n";
	    parsedContent += descText + "<br>\n";
	    if (showDetail) {
		parsedContent += "<p><div class='details' style='display: inline'>\n";
		parsedContent += "<b>" + strbundle.GetStringFromName("details") + "</b>:<br>";
		parsedContent += "<i>" + strbundle.GetStringFromName("feedurl") + "</i>: " + fetchURL + "<br>\n";
		parsedContent += "<i>" + strbundle.GetStringFromName("feedtype") + "</i>: RDF<br>\n";
		parsedContent += "<i>" + strbundle.GetStringFromName("feedlastdownloadedat") + "</i>:" + lastUpdatedAt + "<br>\n";
		parsedContent += "</div>\n";
	    }
	    parsedContent += "</div>\n";
	    dump("parseFeed(): title: " + titleText + "\n");
	    dump("parseFeed(): description: " + descText + "\n");

	    for (var i = 0; i < feed.channel.item.length; i++) {
		parsedContent += "<div class='item'>\n";

		parsedContent += "<b><a href='" + feed.channel.item[i].link + "'" + target + ">";
		if (feed.channel.item[i].title) {
		    parsedContent += feed.channel.item[i].title + "</a><br>\n";
		} else {
		    parsedContent += feed.channel.item[i].link + "</a><br>\n";
		}

		if (feed.channel.item[i].author || feed.channel.item[i].category || feed.channel.item[i].pubDate) {
		    parsedContent += "Posted ";
		}

		if (feed.channel.item[i].author) {
		    parsedContent += "by " + feed.channel.item[i].author + " ";
		}

		if (feed.channel.item[i].category) {
		    parsedContent += "to " + feed.channel.item[i].category + " ";
		}

		if (feed.channel.item[i].pubDate) {
		    parsedContent += "at " + feed.channel.item[i].pubDate + " ";
		}
		parsedContent += "<p>\n";

		if (feed.channel.item[i].description) {
		    parsedContent += feed.channel.item[i].description;
		}
		parsedContent += "</div>\n";
	    }
	    if (feed.channel.copyright) {
		parsedContent += "<div align='center'>Copyright: " + feed.channel.copyright + "</div>";
	    }
	} else if (feed.typeAtom) {
	    // RDF/RSS 1.0 Feeds
	    dump("parseFeed(): feed is Atom\n");

	    parsedContent = "<HTML><HEAD>\n";
	    var titleText = feed.title;
	    var linkText = feed.link_href;
	    var descText = feed.tagline;
	    dump(titleText + "\n");

	    parsedContent += "<TITLE>" + strbundle.GetStringFromName("newsfrom") + titleText + "</TITLE>\n";
	    parsedContent += "<link rel='stylesheet' type='text/css' href='chrome://habarixenu/skin/display.css'>\n";
	    parsedContent += "</HEAD><BODY onload='return true;'>\n";
	    // parsedContent += "<script type='application/x-javascript' src='chrome://habarixenu/content/display.js'/>\n";

	    // TODO must figure out images
	    parsedContent += "<div class='header'>\n";
	    parsedContent += "<b class='header-title' id='header-title'><a href='" + linkText + "'" + target + ">" + titleText + "</a></b><br>\n";
	    parsedContent += descText + "<br>\n";
	    if (showDetail) {
		parsedContent += "<p><div class='details' style='display: inline'>\n";
		parsedContent += "<b>" + strbundle.GetStringFromName("details") + "</b>:<br>";
		parsedContent += "<i>" + strbundle.GetStringFromName("feedurl") + "</i>: " + fetchURL + "<br>\n";
		parsedContent += "<i>" + strbundle.GetStringFromName("feedtype") + "</i>: RDF<br>\n";
		parsedContent += "<i>" + strbundle.GetStringFromName("feedlastdownloadedat") + "</i>: " + lastUpdatedAt + "<br>\n";
		parsedContent += "</div>\n";
	    }
	    parsedContent += "</div>\n";
	    dump("parseFeed(): title: " + titleText + "\n");
	    dump("parseFeed(): description: " + descText + "\n");

	    for (var i = 0; i < feed.entry.length; i++) {
		parsedContent += "<div class='item'>\n";

		parsedContent += "<b><a href='" + feed.entry[i].link_href + "'" + target + ">";
		parsedContent += feed.entry[i].title + "</a><br>\n";

		// If an author exists let us display that information
		if (feed.entry[i].author) {
		    parsedContent += "<div class='credit'>Posted by <a href='" + feed.entry[i].author.url + "'>" + feed.entry[i].author.name + "</a></div>";
		}
		if (feed.entry[i].author || feed.entry[i].category || feed.entry[i].pubDate) {
		    parsedContent += "Posted ";
		}

		if (feed.entry[i].author) {
		    parsedContent += "by " + feed.entry[i].author + " ";
		}

		if (feed.entry[i].category) {
		    parsedContent += "to " + feed.entry[i].category + " ";
		}

		if (feed.entry[i].pubDate) {
		    parsedContent += "at " + feed.entry[i].pubDate + " ";
		}
		parsedContent += "<p>";

		if (feed.entry[i].content) {
		    parsedContent += feed.entry[i].content;
		} else if (feed.entry[i].summary) {
		    parsedContent += feed.entry[i].summary;
		}

		parsedContent += "</div>\n";
	    }
	    if (feed.copyright) {
		parsedContent += "<div align='center'>Copyright: " + feed.copyright + "</div>";
	    }
	    parsedContent += "<p>";
	}
    } else {
	parsedContent = "<HTML><HEAD>\n";
	// parsedContent += "<TITLE>Feed Type not Supported</TITLE>\n";
	parsedContent += "<TITLE>" + strbundle.GetStringFromName("feedtypenotsupported") + "</TITLE>\n";
	parsedContent += "<link rel='stylesheet' type='text/css' href='chrome://habarixenu/skin/display.css'>\n";
	parsedContent += "</HEAD><BODY onload='return true;'>\n";
	parsedContent += "<div class='header'>\n";
	parsedContent += "<b class='header-title' id='header-title'>" + strbundle.GetStringFromName("feedtypenotsupported") + "</b><br>\n";
	parsedContent += strbundle.GetStringFromName("feedtypenotsupportedinfo");
	// parsedContent += "Sorry.  I can't figure out what type of feed this is.  It doesn't seem to be of the type RSS, RDF or Atom";
	parsedContent += "</div>\n";
    }
    parsedContent += "</BODY>\n</HTML>";


    // Open up the visible ibrowser and write the parsed content onto it
    var parsedDocument = window.frames[0].document;
    parsedDocument.body.innerHTML = parsedContent;

    // var tbrowser = document.getElementById("parsed-rss-feed");

    // tbrowser.addTab();
    // tbrowser.removeCurrentTab();
    // var browsers = tbrowser.browsers;
    // var newItem = browsers.length - 1;
    // var newTab = browsers[newItem];
    // var newTab = tbrowser.browsers[0];

    // tbrowser.contentDocument.open();
    // tbrowser.contentDocument.write(parsedContent);
    // tbrowser.contentDocument.close();
    // newTab.contentDocument.reload();

    // alert("Contain tabs " + browsers.length);
    // alert("Length is " + window.frames.length);

    // var displaybrowser = document.getElementById("parsed-rss-feed");
    // dump("Setting src of display area to null");
    // displaybrowser.setAttribute("src", "");

    // parsedDocument.open();
    // parsedDocument.write(parsedContent);
    // parsedDocument.close();

    // Switch to normal cursor
    // win.setAttribute("wait-cursor", "false");

    /*
    progmtr.setAttribute("mode", "determined");
    progmtr.setAttribute("value", "0%");
    win.removeAttribute("wait-cursor");
    */
    // Deactivate the progress meter to indicate work done
    free();
    return true;
}


/*************************************************************************
* A utility function to set the cursor to busy state
*************************************************************************/
function busy() {
    // Activate the progress meter to indicate work happening
    // alert("Setting attribute busy");
    // win.setAttribute("wait-cursor", "true");
    dump("busy: Setting progressmeter to busy\n");
    progmtr = document.getElementById("progmtr");
    progmtr.setAttribute("mode", "undetermined");
}

/*************************************************************************
* A utility function to set the cursor to normal state
*************************************************************************/
function free() {
    // Deactivate the progress meter to indicate work done
    dump("free: Setting progressmeter to normal\n");
    progmtr.setAttribute("mode", "determined");
    progmtr.setAttribute("value", "0%");
    // win.removeAttribute("wait-cursor");
}



/**************************************************************************
* Show information about Habari Xenu
**************************************************************************/
function loadAbout() {
    var tbrowser = document.getElementById("parsed-rss-feed");
    var fu = new FileUtils();
    // var aboutFile = new File(fu.chromeToPath('chrome://habarixenu/locale/about.html'));
    var aboutPath = fu.chromeToPath('chrome://habarixenu/locale/about.html');

    // Some stuff we need to do for Windows
    var plat = navigator.platform;
    var platRE = new RegExp("win","i");
    if(plat.search(platRE) != -1) {
	aboutPath = unescape(aboutPath);

	var re2 = new RegExp('^/');
	aboutPath = aboutPath.replace(re2,'');
		
	var re1 = new RegExp('/','g');
	aboutPath = aboutPath.replace(re1,'\\');
    }

    var aboutFile = new File(aboutPath);

    aboutFile.open('r');
    var aboutContent = aboutFile.read();
    aboutFile.close();

    tbrowser.contentDocument.open();
    tbrowser.contentDocument.write(aboutContent);
    tbrowser.contentDocument.close();

    return true;
}

/**************************************************************************
* This function gets called when we need to open the settings editor
**************************************************************************/
function openSettingsEditor() {
    dump("openSettingsditor(): Opening Settings editor\n");

    // Open a new modal dialog showing the settingseditor xul as chrome
    // pass it a reference to the feedsTree
    var settingsURL = "chrome://habarixenu/content/settingseditor.xul";
    window.openDialog(settingsURL,"","chrome,modal, width=600, height=550", feedsTree);

    dump("openSettingsditor(): Finished opening Settings editor\n");
    return true;
}



/**************************************************************************
* This function gets called when we need to open the bookmarks editor
**************************************************************************/
function openBookmarksEditor() {
    dump("openBookmarksEditor(): Opening Bookmarks editor\n");

    // Open a new window showing the bookmark editor xul as chrome
    var settingsURL = "chrome://communicator/content/bookmarks/bookmarksManager.xul";
    window.openDialog(settingsURL,"","chrome,modal, width=340, height=270");
    // For some reason I am unable to open a non-modeal nondialog window using the foll
    // in Version Moz 1.7.1.  This used to work in <= 1.5
    // window.open(settingsURL,"","chrome");

    dump("openBookmarksEditor(): Finished opening Bookmarks editor\n");
    return true;
}


/**************************************************************************
* Close the application
**************************************************************************/
function closeHabariXenu() {
    dump("closeHabariXenu(): Closing window\n");
    window.close();
}
