/***** BEGIN LICENSE BLOCK *****
   - Version: MPL 1.1/GPL 2.0/LGPL 2.1
   -
   - The contents of this file are subject to the Mozilla Public License Version
   - 1.1 (the "License"); you may not use this file except in compliance with
   - the License. You may obtain a copy of the License at
   - http://www.mozilla.org/MPL/
   -
   - Software distributed under the License is distributed on an "AS IS" basis,
   - WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
   - for the specific language governing rights and limitations under the
   - License.
   -
   - The Original Code is _by Sudhakar "Thaths" Chandrasekharan_.
   -
   - The Initial Developer of the Original Code is
   - _Sudhakar "Thaths" Chandrasekharan <thaths@openscroll.org>_.
   - Portions created by the Initial Developer are Copyright (C) 2003-2004
   - the Initial Developer. All Rights Reserved.
   -
   - Contributor(s):
   - Sudhakar "Thaths" Chandra <thaths@openscroll.org> (original author)
   -
   - Alternatively, the contents of this file may be used under the terms of
   - either the GNU General Public License Version 2 or later (the "GPL"), or
   - the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
   - in which case the provisions of the GPL or the LGPL are applicable instead
   - of those above. If you wish to allow use of your version of this file only
   - under the terms of either the GPL or the LGPL, and not to allow others to
   - use your version of this file under the terms of the MPL, indicate your
   - decision by deleting the provisions above and replace them with the notice
   - and other provisions required by the LGPL or the GPL. If you do not delete
   - the provisions above, a recipient may use your version of this file under
   - the terms of any one of the MPL, the GPL or the LGPL.
   -
   - ***** END LICENSE BLOCK *****/

/**************************************************************************
* This file contains all the JavaScript needed by settings.xul.
* A lot of the ideas here are borrowed from the rssreader extension
**************************************************************************/
// Some XPCOM constants we need to walk the bookmarks tree
const RDF = Components.classes['@mozilla.org/rdf/rdf-service;1'].getService(Components.interfaces.nsIRDFService);
const RDFC = Components.classes['@mozilla.org/rdf/container;1'].createInstance(Components.interfaces.nsIRDFContainer);
const XUL_NS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
const NC_NS = "http://home.netscape.com/NC-rdf#";
const BMDS = Components .classes["@mozilla.org/rdf/datasource;1?name=bookmarks"].getService(Components.interfaces.nsIRDFDataSource); 
const RDFCU = Components.classes['@mozilla.org/rdf/container-utils;1'].getService(Components.interfaces.nsIRDFContainerUtils);
const XPPREF = Components.classes["@mozilla.org/preferences;1"].getService(Components.interfaces.nsIPrefBranch);
var gNameArc;			    // Arc pointing to Name field in bookmarks
var selectedFolderId;		    // The ID of the folder selected by the user
var prefFolder;			    // The folder name as set in preferences
var prefUpdateInterval;		    // Update interval as set in preferences
var prefOpenInSame;		    // Display settings as set in preferences
var menuList;			    // The pulldown menulist in the dialog
var updateIntervalElement;	    // The text box containing the update interval
var openInSameElement;
var showDetailsElement;
var strbundle;

// The main window's subscriptions tree passed to us as an argument
var bTree = window.arguments[0];
var caller = window.opener;

/**************************************************************************
* User has clicked OK.  Find out which item was selected, set it in
* prefs.js and return
**************************************************************************/
function doOK() {
    dump("doOK(): Entering\n");

    // Find out which element was selected in bookmarksFeedsFolderMenu
    menuList = document.getElementById("bookmarkFeedsFolder");
    updateIntervalElement = document.getElementById("update-interval");
    openInSameElement = document.getElementById("open-in-same");
    showDetailsElement = document.getElementById("show-details");
    var menuSelectedElement = menuList.selectedIndex;
    var updateIntervalSet = parseInt(updateIntervalElement.value);

    if (menuSelectedElement <= 0) {
	// User has not selected a bookmarks folder
	dump("doOK(): No folder was selected by user\n");
	alert(strbundle.GetStringFromName("errnofolderselected"));
	return false;
    } else  {
	dump("doOK(): Item number " + menuSelectedElement + " selected.  Setting preference\n");

	if (updateIntervalSet > 0 && updateIntervalSet < 100 ) {
	    try {
		// Set the preferences
		XPPREF.setCharPref("extensions.habarixenu.feeds_folder", selectedFolderId);
		XPPREF.setIntPref("extensions.habarixenu.update_interval", updateIntervalSet);
		XPPREF.setBoolPref("extensions.habarixenu.show_details", showDetailsElement.checked);

		// XPPREF.setBoolPref("extensions.habarixenu.open_in_same", openInSameElement.checked);

		// Set the variables in habarixenu.js
		caller.updateInterval = updateIntervalSet;
		caller.showDetail = showDetailsElement.checked;

		// Make the feeds tree point to the correct place
		bTree.setAttribute("ref", selectedFolderId);
		bTree.builder.rebuild();
	    } catch(e) {
		alert(strbundle.GetStringFromName("errorsettingprefs") + " : " + e);
		return false;
	    }
	} else {
	    dump("doOK(): Incorrect update interval\n");
	    alert(strbundle.GetStringFromName("errbadupdateinterval"));
	    return false;
	}
    }


    dump("doOK(): Leaving\n");
    return true;
}


/**************************************************************************
* This function gets called when the user selects an item in the pulldown
* menu.  We set a variable with the ID of the selected element
**************************************************************************/
function selectBookmarkFolder(aEvent) {
    dump("selectBookmarkFolder(): Entering\n");

    selectedFolderId = aEvent.target.id;
    dump("selectBookmarkFolder(): Folder selected is " + selectedFolderId + "\n");

    dump("selectBookmarkFolder(): Leaving\n");
}


/**************************************************************************::
* User has clicked Cancel.
**************************************************************************/
function doCancel() {
    dump("doCancel(): Closing\n");
    return;
}


/**************************************************************************
* Populate the tree from the Datasource. See above for consts that we set
* This function gets called on the settings editor's onload event
**************************************************************************/
function buildMenuFromDataSource() {
    dump("buildMenuFromDataSource(): Beginning to build menu from RDF datasource\n");

    strbundle=srGetStrBundle("chrome://habarixenu/locale/strings.properties");

    // Was any folder set as the preferred folder in prefs
    dump("buildMenuFromDataSource(): Getting user preferences\n");
    if(XPPREF.getPrefType("extensions.habarixenu.feeds_folder") == XPPREF.PREF_INVALID){
	prefFolder = "NC:BookmarksRoot";	// Nothing set.  Set it to the top of bookmarks RDF
    } else {
	prefFolder = XPPREF.getCharPref("extensions.habarixenu.feeds_folder").toString();
    }

    // Was any update interval set as the preferred in prefs
    if(XPPREF.getPrefType("extensions.habarixenu.update_interval") == XPPREF.PREF_INVALID){
	dump("buildMenuFromDataSource(): No update interval set. Setting to default of 60.\n");
	prefUpdateInterval = 60;		// Nothing set.  Set it to 60 minutes
    } else {
	prefUpdateInterval = XPPREF.getIntPref("extensions.habarixenu.update_interval");
	dump("buildMenuFromDataSource(): Preferred update interval is " + prefUpdateInterval + "\n");
    }

    // Was any update interval set as the preferred in prefs
    /*
    if(XPPREF.getPrefType("extensions.habarixenu.open_in_same") == XPPREF.PREF_INVALID){
	dump("buildMenuFromDataSource(): No pref for open_in_same set.  Assuming false\n");
	prefOpenInSame = false;		// Nothing set.  Set to false
    } else {
	prefOpenInSame = XPPREF.getBoolPref("extensions.habarixenu.open_in_same");
	dump("buildMenuFromDataSource(): Preferred display preference is " + prefOpenInSame + "\n");
    }
    */

    if(XPPREF.getPrefType("extensions.habarixenu.show_details") == XPPREF.PREF_INVALID){
	dump("buildMenuFromDataSource(): No pref for open_in_same set.  Assuming false\n");
	prefShowDetails = false;		// Nothing set.  Set to false
    } else {
	prefShowDetails = XPPREF.getBoolPref("extensions.habarixenu.show_details");
	dump("buildMenuFromDataSource(): Preferred display preference is " + prefShowDetails + "\n");
    }

    menuList = document.getElementById("bookmarkFeedsFolder");
    var menuPopup = document.getElementById("bookmarksFeedsFolderMenu");

    gNameArc = RDF.GetResource(NC_NS + "Name");

    // Remove any children menuPopup might have
    while (menuPopup.hasChildNodes()) {
	menuPopup.removeChild(menuPopup.firstChild);
    }

    var newMenuItem = document.createElementNS(XUL_NS, "menuitem");
    newMenuItem.setAttribute("label", "Bookmarks");
    newMenuItem.setAttribute("id", "NC:BookmarksRoot");
    menuPopup.appendChild(newMenuItem);

    var bookmarksRoot = RDF.GetResource("NC:BookmarksRoot");

    // Descend into this folder and read all its contents
    descendFolder(menuPopup, bookmarksRoot, 1, prefFolder);

    // Now set the update interval
    dump("buildMenuFromDataSource(): Setting prefUpdateInterval to " + prefUpdateInterval + "\n");
    updateIntervalElement = document.getElementById("update-interval");
    updateIntervalElement.value = prefUpdateInterval;

    // Check on uncheck the Display Preference
    /*
    dump("buildMenuFromDataSource(): Setting Display Preference to " + prefOpenInSame + "\n");
    openInSameElement = document.getElementById("open-in-same");
    openInSameElement.checked = prefOpenInSame;
    */

    /*
    if (prefOpenInSame) {
	openInSameElement.checked = true;
    } else {
	openInSameElement.checked = false;
    }
    */

    dump("buildMenuFromDataSource(): Setting Show Details to " + prefShowDetails + "\n");
    showDetailsElement = document.getElementById("show-details");
    showDetailsElement.checked = prefShowDetails;

    dump("buildMenuFromDataSource(): Finished rebuilding menu from RDF datasource.\n");
}


/**************************************************************************
* A recursive function that we will use to descend into each folder and
* subfolder of the bookmarks tree and create menuitems for each folder
**************************************************************************/
function descendFolder(aPopup, aFolder, aDepth) {
    RDFC.Init(BMDS, aFolder);

    var children = RDFC.GetElements();
    while (children.hasMoreElements()) {
	var curr = children.getNext();
	if (RDFCU.IsContainer(BMDS, curr)) {
	    curr = curr.QueryInterface(Components.interfaces.nsIRDFResource);
	    var element = document.createElementNS(XUL_NS, "menuitem");
	    var name = BMDS.GetTarget(curr, gNameArc, true).QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
	    var indentation = new Array(aDepth + 1).join("  ");
	    element.setAttribute("label", indentation + name);
	    element.setAttribute("id", curr.Value);
	    aPopup.appendChild(element);
	    if (curr.Value == prefFolder) {
		// This item is currently set in prefs as the preferred folder
		// select it
		menuList.selectedItem = element;
		selectedFolderId = prefFolder;
	    }
	    descendFolder(aPopup, curr, ++aDepth);
	    --aDepth;
	}
    }
}


/**************************************************************************
* User has clicked Uninstall.
**************************************************************************/
function uninstallHX() {
    if (confirm(strbundle.GetStringFromName("uninstallconfirm"))) {
	var oExtUninstall = new ExtensionUninstall("urn:mozilla:package:habarixenu");
	var success = oExtUninstall.uninstall();
	oExtUninstall.showLogDialog(true, opener);
	window.opener.close();
	window.close();
    } else {
	alert(strbundle.GetStringFromName("uninstallcancel"));
    }
}

/**************************************************************************
* User is asking us to set tabbed browsing appropriately
**************************************************************************/
function setTabbedBrowsing() {
    dump("setTabbedBrowsing(): Entered\n");
    if (confirm(strbundle.GetStringFromName("settabbrowsingconfirm"))) {
	dump("setTabbedBrowsing(): User is persistent\n");
	try {
	    dump("setTabbedBrowsing(): Setting tabbed browsing\n");
	    XPPREF.setBoolPref("browser.tabs.loadInBackground", true);
	    XPPREF.setBoolPref("browser.tabs.opentabfor.middleclick", true);

	    alert(strbundle.GetStringFromName("settabbrowsingok"));
	} catch (e) {
	    dump("setTabbedBrowsing(): Error Setting tabbed browsing " + e + "\n");
	}
    }
    dump("setTabbedBrowsing(): Leaving\n");
}
